@@ -300,7 +300,7 @@ clip_erase_sp <- function(target, overlay_layer, bbox, type, remove_slivers, for
 
   check_overlay_bbox(overlay_layer = overlay_layer, bbox = bbox, type = type)
 
-  target_proj <- sp::proj4string(target)
+  target_proj <- slot(target, "proj4string")
 
   if (is.null(bbox)) {
     if (!is(overlay_layer, "SpatialPolygons")) stop(type, " must be of class SpatialPolygons or SpatialPolygonsDataFrame")
