@@ -256,8 +256,9 @@ test_that("ms_simplify works with very small values of 'keep", {
 
 # SF ----------------------------------------------------------------------
 
+multipoly_sf <- st_as_sf(multipoly_spdf)
+
 test_that("ms_simplify works with sf", {
-  multipoly_sf <- st_as_sf(multipoly_spdf)
   line_sf <- st_as_sf(line_spdf)
   expect_is(ms_simplify(multipoly_sf), c("sf", "data.frame"))
   expect_is(ms_simplify(line_sf), c("sf", "data.frame"))
@@ -304,3 +305,13 @@ test_that("ms_simplify works with various column types", {
   xsf$check_me <- raw(nr)
   expect_warning(simp_xsf <- ms_simplify(xsf), "NAs introduced by coercion")
 })
+
+
+# units -------------------------------------------------------------------
+
+test_that("ms_simplify works with sf objects containing units", {
+  multipoly_sf$area = sf::st_area(multipoly_sf)
+  expect_warning(multipoly_sf_simple <- ms_simplify(multipoly_sf), "units")
+  expect_is(multipoly_sf_simple, c("sf", "data.frame"))
+  expect_is(multipoly_sf_simple$area, c("numeric"))
+})
